@@ -8,6 +8,7 @@ MetaSpecDefinition into complete SpecKitProject structures.
 import re
 import textwrap
 from datetime import datetime
+from importlib.metadata import version
 from pathlib import Path
 from typing import Any
 
@@ -109,6 +110,19 @@ class Generator:
 
         return project
 
+    def _get_metaspec_version(self) -> str:
+        """
+        Get the MetaSpec package version from metadata.
+
+        Returns:
+            Version string (e.g., "0.5.1")
+        """
+        try:
+            return version("meta-spec")
+        except Exception:
+            # Fallback to a default version if package metadata is not available
+            return "0.0.0"
+
     def _create_template_context(self, meta_spec: MetaSpecDefinition) -> dict[str, Any]:
         """
         Create template rendering context from MetaSpecDefinition.
@@ -188,7 +202,7 @@ class Generator:
             "dependencies": meta_spec.dependencies or [],
             "year": datetime.now().year,
             "date": datetime.now().date().isoformat(),
-            "metaspec_version": "0.1.0",  # TODO: Get from package metadata
+            "metaspec_version": self._get_metaspec_version(),
         }
 
     def _select_templates(self, meta_spec: MetaSpecDefinition) -> dict[str, str]:
@@ -216,7 +230,8 @@ class Generator:
             ("base/pyproject.toml.j2", "pyproject.toml"),
             ("base/constitution.md.j2", "memory/constitution.md"),
             ("base/.gitignore.j2", ".gitignore"),
-            ("base/specs/README.md.j2", "specs/README.md"),  # Phase 2: specs/ directory
+            ("base/specs/README.md.j2", "specs/README.md"),  # specs/ directory guide
+            ("base/templates/README.md.j2", "templates/README.md"),  # templates/ directory guide
             (
                 "base/scripts/bash/create-new-feature.sh.j2",
                 "scripts/bash/create-new-feature.sh",
@@ -255,15 +270,17 @@ class Generator:
                     source = f"library/generic/{subdir}"
 
                 # Copy template file (required)
+                # Organize by source to maintain specification system boundaries
                 template_name = f"{sc.name}-template.md"
                 source_template = f"{source}/templates/{template_name}.j2"
-                output_template = f"templates/{template_name}"
+                output_template = f"templates/{sc.source}/templates/{template_name}"
                 template_map[source_template] = output_template
 
                 # Copy command file (optional - some sources like "generic" may not have commands)
+                # Organize by source to avoid naming conflicts
                 command_name = f"{sc.name}.md"
                 source_command = f"{source}/commands/{command_name}.j2"
-                output_command = f"templates/commands/{command_name}"
+                output_command = f"templates/{sc.source}/commands/{command_name}"
                 # Only add to template_map if command file exists
                 # The actual existence check happens during rendering, where missing files are skipped
                 template_map[source_command] = output_command
@@ -271,17 +288,21 @@ class Generator:
         # 3. MetaSpec commands and templates for speckit development → .metaspec/
         # These provide AI-assisted workflow for developing the speckit itself
         # Three-layer architecture:
-        #   - SDS (Spec-Driven Specification): 4 commands for protocol definition
+        #   - SDS (Spec-Driven Specification): 8 commands for specification definition
         #   - SDD (Spec-Driven Development): 8 commands for toolkit development
         #   - Evolution: 3 shared commands for specification evolution
 
-        # SDS commands (4): Protocol specification definition
+        # SDS commands (8): Domain specification definition
         # File naming: metaspec.sds.{command}.md to use /metaspec.sds.{command} prefix
         sds_commands = [
-            "constitution",  # Define protocol principles
-            "specify",  # Define protocol entities
-            "clarify",  # Resolve protocol ambiguities
-            "analyze",  # Check protocol consistency
+            "constitution",  # Define specification design principles
+            "specify",  # Define specification entities and operations
+            "clarify",  # Resolve specification ambiguities
+            "plan",  # Plan specification architecture and sub-specifications
+            "tasks",  # Break down specification work
+            "implement",  # Write specification documents
+            "checklist",  # Generate quality checklist for specification
+            "analyze",  # Check specification consistency
         ]
 
         for cmd in sds_commands:
@@ -444,7 +465,8 @@ class Generator:
 
         # Additional directories
         directories.add(Path("templates"))
-        directories.add(Path("templates/commands"))  # AI slash command files (packaged)
+        # Note: templates/{source}/commands/ and templates/{source}/templates/
+        # are automatically tracked via files dict (Line 414-416)
         directories.add(Path("memory"))
         directories.add(Path("examples"))
         directories.add(Path("specs"))  # Phase 2: Specifications directory
@@ -489,18 +511,34 @@ class Generator:
                 )
             else:
                 # Generate function with options if present
+                params_list = ["spec_file: str"]
+                option_prints = ['console.print(f"[green]{cmd_name.title()}:[/green] {{spec_file}}")']
+
                 if cmd.get("options"):
-                    # TODO: Handle options properly
-                    params = "spec_file: str"
-                else:
-                    params = "spec_file: str"
+                    for opt in cmd["options"]:
+                        opt_name = opt["name"]
+                        opt_type = opt["type"]
+                        opt_required = opt.get("required", False)
+
+                        # Build parameter declaration
+                        if opt_required:
+                            params_list.append(f"{opt_name}: {opt_type}")
+                        else:
+                            # Optional parameter with default None
+                            params_list.append(f"{opt_name}: {opt_type} = None")
+
+                        # Add print statement for the option
+                        option_prints.append(f'console.print(f"[blue]{opt_name.title()}:[/blue] {{{opt_name}}}")')
+
+                params = ", ".join(params_list)
+                option_code = "\n                        ".join(option_prints)
 
                 command_functions.append(
                     textwrap.dedent(f'''
                     @app.command()
                     def {cmd_name}({params}):
                         """{cmd_desc}"""
-                        console.print(f"[green]{cmd_name.title()}:[/green] {{spec_file}}")
+                        {option_code}
                         # TODO: Implement {cmd_name}
                 ''').strip()
                 )
